==> vvauditor_0.6.0.tar.gz: vvauditor/README.md <==
# vvauditor <a href='https://github.com/vusaverse/vvauditor'><img src="man/figures/hex-vvauditor.png" style="float:right; height:200px;" height="200" align="right"/></a>

  <!-- badges: start -->
[![R-CMD-check](https://github.com/vusaverse/vvauditor/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/vusaverse/vvauditor/actions/workflows/R-CMD-check.yaml)

[![CodeFactor](https://www.codefactor.io/repository/github/vusaverse/vvauditor/badge)](https://www.codefactor.io/repository/github/vusaverse/vvauditor)
[![CRAN status](https://www.r-pkg.org/badges/version/vvauditor)](https://CRAN.R-project.org/package=vvauditor/)
<a href="https://diffify.com/R/vvauditor" target="_blank"><img src="https://diffify.com/diffify-badge.svg" alt="The diffify page for the R package vvauditor" style="width: 100px; max-width: 100%;"></a>
[![CRAN last month downloads](https://cranlogs.r-pkg.org/badges/last-month/vvauditor?color=green/)](https://cran.r-project.org/package=vvauditor/)
[![CRAN last month downloads](https://cranlogs.r-pkg.org/badges/grand-total/vvauditor?color=green/)](https://cran.r-project.org/package=vvauditor/)
  <!-- badges: end -->


The `vvauditor` package is an R package designed to validate the integrity of data by providing a comprehensive set of assertion tests. These tests allow users to check for specific conditions or properties within a dataset, ensuring the accuracy and reliability of the data. The package aims to facilitate quality control checks in data analysis workflows and assists in identifying and correcting any errors or inconsistencies in the data.

# Installation

To install the vvauditor package, you can use the install.packages() function in R:

```r

install.packages("vvauditor")

```

# Usage

Once the package is installed, you can load it into your R session using the library() function:

```r
library(vvauditor)

```

# Assertion Tests

The vvauditor package provides a range of assertion tests that can be applied to datasets. These tests include checks for missing values, outliers, distributional assumptions, and more. By incorporating these tests into your data analysis workflow, you can ensure the quality and reliability of your data.

For more information on the available assertion tests and how to use them, please refer to the package documentation.


# Contributing

If you're interested in contributing to the vvauditor package, you can follow these steps:

1. Fork the vvauditor repository on GitHub.
2. Make your desired changes to the code.
3. Submit a pull request to the main repository.

Please refer to the contribution guidelines in the package repository for more information on how to contribute.

==> vvauditor_0.8.0.tar.gz: vvauditor/README.md <==
# vvauditor <a href='https://github.com/vusaverse/vvauditor'><img src="man/figures/hex-vvauditor.png" style="float:right; height:200px;" height="200" align="right"/></a>

  <!-- badges: start -->
[![R-CMD-check](https://github.com/vusaverse/vvauditor/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/vusaverse/vvauditor/actions/workflows/R-CMD-check.yaml)

[![CodeFactor](https://www.codefactor.io/repository/github/vusaverse/vvauditor/badge)](https://www.codefactor.io/repository/github/vusaverse/vvauditor)
[![Codecov test coverage](https://codecov.io/gh/vusaverse/vvauditor/branch/master/graph/badge.svg)](https://app.codecov.io/gh/vusaverse/vvauditor?branch=master)
[![CRAN status](https://www.r-pkg.org/badges/version/vvauditor)](https://CRAN.R-project.org/package=vvauditor/)
<a href="https://diffify.com/R/vvauditor" target="_blank"><img src="https://diffify.com/diffify-badge.svg" alt="The diffify page for the R package vvauditor" style="width: 100px; max-width: 100%;"></a>
[![CRAN last month downloads](https://cranlogs.r-pkg.org/badges/last-month/vvauditor?color=green/)](https://cran.r-project.org/package=vvauditor/)
[![CRAN last month downloads](https://cranlogs.r-pkg.org/badges/grand-total/vvauditor?color=green/)](https://cran.r-project.org/package=vvauditor/)
  <!-- badges: end -->


The `vvauditor` package is an R package designed to validate the integrity of data by providing a comprehensive set of assertion tests. These tests allow users to check for specific conditions or properties within a dataset, ensuring the accuracy and reliability of the data. The package aims to facilitate quality control checks in data analysis workflows and assists in identifying and correcting any errors or inconsistencies in the data.

# Installation

To install the vvauditor package, you can use the install.packages() function in R:

```r

install.packages("vvauditor")

```

# Usage

Once the package is installed, you can load it into your R session using the library() function:

```r
library(vvauditor)

```

# Assertion Tests

The vvauditor package provides a range of assertion tests that can be applied to datasets. These tests include checks for missing values, outliers, distributional assumptions, and more. By incorporating these tests into your data analysis workflow, you can ensure the quality and reliability of your data.

For more information on the available assertion tests and how to use them, please refer to the package documentation.


# Contributing

If you're interested in contributing to the vvauditor package, you can follow these steps:

1. Fork the vvauditor repository on GitHub.
2. Make your desired changes to the code.
3. Submit a pull request to the main repository.

Please refer to the contribution guidelines in the package repository for more information on how to contribute.
